<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+34"/>
        <source>Automatically scale grid</source>
        <translation>Automatyczne skalowanie siatki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Automatically scale meta grid</source>
        <translation>Automatyczne skalowanie meta siatki</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Solid grid lines</source>
        <translation>Linie ciągłe siatki</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Minimal grid spacing (px):</source>
        <translation>Minimalne odstępy siatki (piksele):</translation>
    </message>
</context>
<context>
    <name>GridPreferences</name>
    <message>
        <location filename="../GridPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Widok graficzny</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Grid</source>
        <translation>Siatka</translation>
    </message>
</context>
</TS>
